# AI Explainability 360 Examples and Tutorials

This directory contains a diverse collection of jupyter notebooks that use AI Explainability 360 toolkit in various ways. Both tutorials and examples illustrate working code using the toolkit.  Tutorials provide additional discussion that walks 
the user through the various steps of the notebook.

## Tutorials

- [Credit Approval Tutorial](./tutorials/HELOC.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/tutorials/HELOC.ipynb)]<br/>Shows how to explain credit approval models that use the FICO Explainable Machine Learning Challenge dataset.

- [Medical Expenditure Tutorial](./tutorials/MEPS.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/tutorials/MEPS.ipynb)]<br/>Shows how to create interpretable machine learning models in a care management scenario using Medical Expenditure Panel Survey data.

- [Dermoscopy](./tutorials/dermoscopy.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/tutorials/dermoscopy.ipynb)]<br/>Shows how to explain dermoscopic image datasets used to train machine learning models that help physicians diagnose skin diseases.

- [Health and Nutrition Survey](./tutorials/CDC.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/tutorials/CDC.ipynb)]<br/>Shows how to quickly understand the National Health and Nutrition Examination Survey datasets to hasten research in epidemiology and health policy.

- [Proactive Retention](./tutorials/retention.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/tutorials/retention.ipynb)]<br/>Shows how to explain predictions of a model that recommends employees for retention actions from a synthesized human resources dataset.

## Examples
- [CEMExplainer using MNIST dataset](./contrastive/CEM-MNIST.ipynb)  [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/contrastive/CEM-MNIST.ipynb)]

- [CEM_MAFImageExplainer using CelabA dataset](./contrastive/CEM-MAF-CelebA.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/contrastive/CEM-MAF-CelebA.ipynb)]

- [DIPVAEExplainer using Fashion-MNIST dataset](./dipvae/DIPVAE-FMNIST.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/dipvae/DIPVAE-FMNIST.ipynb)]

- [ProfweightExplainer using CIFAR dataset](./profwt/Prof-Weight.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/profwt/Prof-Weight.ipynb)]

- [ProtodashExplainer using NHANES-CDC dataset](./protodash/Protodash-CDC.ipynb) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/blob/master/examples/protodash/Protodash-CDC.ipynb)]

- [GLRMExplainer and BRCGExplainer using Boston, Breast-cancer datasets](./rbm) [[on nbviewer](https://nbviewer.jupyter.org/github/IBM/AIX360/tree/master/examples/rbm/)]

